/* Copyright (c) 2009 Ondrej Donek.
   See the file LICENSE.txt for licensing information. */

/**
 * Main controller object of note dialog
 * 
 * @type Object
 */
var tbNoteDialog = {
	
	/** 
	 * Holds instance of object describing target email message
	 * @type Object|NULL
	 */
	_targetMsg: null,
	
	/**
	 * Holds instance of object representing edited note.
	 * @type Object|NULL
	 */
	_editedNote: null,
	
	/**
	 * Fired when dialog is loading.
	 * 
	 * @return void
	 */
	onLoad: function() {
		// Check if we editing existing note or creating new
		if(typeof(window.arguments[0].inn.note) != "undefined") {
			if(window.arguments[0].inn.note != null) {
				this._editedNote = window.arguments[0].inn.note;
			}
		}
		
		// Check if we targeting note to some message
		// TODO When we editing note target message can be blank so load 
		//      subject by self here!
		if(typeof(window.arguments[0].inn.msg) != "undefined") {
			if(window.arguments[0].inn.msg != null) {
				this._targetMsg = window.arguments[0].inn.msg;
			}
		}
		
		this._updateUi();
	},
	
	/** 
	 * Updates dialog UI.
	 * 
	 * @return void
	 */
	_updateUi: function() {
		var dlg = document.getElementById("tbnotes-note-dialog");
		var cont1 = document.getElementById("tbnotedialog_targetCont-hbox");
		var cont2 = document.getElementById("tbnotedialog_createdCont-hbox");
		
		if(this._targetMsg != null) {
			var targetElm = document.getElementById("tbnotedialog_target-textbox");
			
			targetElm.value = this._targetMsg.subject;
			targetElm.setAttribute("tooltiptext", this._targetMsg.subject);
			
			if(cont1.hasAttribute("collapsed")) {
				cont1.removeAttribute("collapsed");
			}
		} else {
			cont1.setAttribute("collapsed", "true");
		}
		
		if(this._editedNote != null) {
			var createdElm = document.getElementById("tbnotedialog_created-textbox");
			var titleElm = document.getElementById("tbnotedialog_title-textbox");
			var bodyElm = document.getElementById("tbnotedialog_body-textbox");
			
			createdElm.value = this._editedNote.created;
			titleElm.value = this._editedNote.title;
			bodyElm.value = this._editedNote.body;
			
			if(cont2.hasAttribute("collapsed")) {
				cont2.removeAttribute("collapsed");
			}
			
			// TODO Use stringbunles!
			var title = dlg.getAttribute("titleEdit") + " #" + this._editedNote.id;
			
			dlg.setAttribute("title", title);
		} else {
			cont2.setAttribute("collapsed", "true");
			dlg.setAttribute("title", dlg.getAttribute("titleAdd"));
		}
	},
	
	/** 
	 * Fired when user accepted the note dialog.
	 * 
	 * @return boolean
	 */
	onAccept: function() {
		try {
		
		var titleElm = document.getElementById("tbnotedialog_title-textbox");
		var bodyElm = document.getElementById("tbnotedialog_body-textbox");
		
		// TODO Check if title is empty!
		// TODO Check if body is empty!
		// TODO What if target was cleared by user?
		
		if(this._editedNote == null) {
			// We are adding new note
			this._editedNote = {};
			this._editedNote.title = titleElm.value;
			this._editedNote.body = bodyElm.value;
			
			if(this._targetMsg != null) {
				this._editedNote.target = "message";
				this._editedNote.targetKey = this._targetMsg.key;
			}
		}
		else {
			// We are editing note
			this._editedNote.title = titleElm.value;
			this._editedNote.body = bodyElm.value;
		}
		
		window.arguments[0].out = this._editedNote;
		
		} catch(e) { CU.reportError(e); }
		
		return true;
	}, 
	
	/**
	 * Fired when user canceled the note dialog.
	 * 
	 * @return boolean
	 */
	onCancel: function() {
		var pref = TBNOTES_PREFS_KEY + "dont_show_close_confirm";
		
		// Check if user want to see confirmation dialog
		if(TBNOTES_PREFS.prefHasUserValue(pref) === true) {
			if(TBNOTES_PREFS.getBoolPref(pref) === true) {
				return true;
			}
		}
		
		// Show confirmation if user really want to close unsaved note
		var prompts = CC["@mozilla.org/embedcomp/prompt-service;1"].
				getService(CI.nsIPromptService);
		
		// TODO Use stringbundles!
		var title = "Note dialog";
		var desc = "Do you really want to close unsaved note?";
		var question = "Do not ask me again.";
		var check = { value: false };
		var res = prompts.confirmCheck(window, title, desc, question, check);
		
		TBNOTES_PREFS.setBoolPref(pref, check.value);
		
		return res;
	},
	
	/**
	 * Performs requested command
	 * 
	 * @param aCmdName {string}
	 * @return void
	 */
	doCommand: function(aCmdName) {
		switch(aCmdName) {
			case "bold":
			case "italic":
			case "underline":
			// Clears note target
			case "clear_target":
				alert("Not implemented yet!");
				break;
			
			default:
				CU.reportError("tbNoteDialog.doCommand:: undefined command '" + aCmdName + "'.");
				break;
		}
	}
	
}; // End of tbNoteDialog
